@@ -8,15 +8,16 @@
  */
 
 #ifndef DENEMO_DATASTRUCTURES
-
 #define DENEMO_DATASTRUCTURES
-using namespace::std;
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* Include the internationalization stuff.  */
 /* Only if not on Cygwin, because libintl does not work with mingw */
 /* G_OS_WIN32 is defined in gtk.h for mingw */
 
-#include <gtk/gtk.h>
-#include <gmodule.h>
+
 #ifndef G_OS_WIN32
 # include <libintl.h>
 # include <locale.h>
@@ -34,11 +35,9 @@ using namespace::std;
 # define textdomain(x)
 #endif
 
-
-
-
-#include <gtk/gtk.h>
+#include "denemo_objects.h"
 #include <glib.h>
+#include <gmodule.h>
 
 #if GTK_MAJOR_VERSION <= 1
 #define GtkTextBuffer GtkWidget
@@ -87,8 +86,8 @@ enum objtype
   TIMESIG,
   KEYSIG,
   BARLINE,
-  LILYDIRECTIVE,
-  COMMENT,
+ // LILYDIRECTIVE,
+ // COMMENT,
   STEMDIRECTIVE,
   MEASUREBREAK,
   DYNAMIC,
@@ -98,19 +97,20 @@ enum objtype
   FIGURE
 };
 
-enum headtype
-{ 
-  DENEMO_NORMAL_NOTEHEAD,
-  DENEMO_CROSS_NOTEHEAD,
-  DENEMO_HARMONIC_NOTEHEAD,
-  DENEMO_DIAMOND_NOTEHEAD
-};
+
+typedef enum tuplet_type {
+	DUPLET,
+	TRIPLET,
+	QUADTUPLET,
+	QUINTUPLET,
+	SEXTUPLET,
+	SEPTUPLET	
+}tuplet_type;
 
 enum input_mode {
   INPUTNORMAL,
   INPUTREST,
   INPUTBLANK,
-  INPUTBLANKREST,
   REPLACE,
   TRAVERSE
 };
@@ -121,277 +121,10 @@ enum action_type {
   ACTION_CHANGE
 };
 
-typedef struct grace
-{
- 
-  gboolean on_beat;
-  gint duration;
-}
-grace;
-  
-typedef struct note
-{
-  gint mid_c_offset;
-  gint enshift;
-  gboolean reversealign;
-  gboolean showaccidental;
-  /* Holds number of pixels to the left of the notehead that the
-     accidental should be drawn at.  */
-  gint position_of_accidental;
-  /* Holds y co-ordinate for drawing rather than recalculating it each
-     run through the drawing loop.  */
-  gint y;
-  /* Holds note head type.  */
-  enum headtype noteheadtype;
-  /* Holds x offset from default position.  */
-  gint x_off;
-  /* Holds y offset from default position.  */
-  gint y_off;
- 
-}
-note;
-
-enum ornament {
-  STACCATO=1,
-  D_ACCENT,
-  CODA,
-  FERMATA,
-  TENUTO,
-  TRILL,
-  TURN,
-  REVERSETURN,
-  MORDENT,
-  STACCATISSIMO,
-  MARCATO,
-  UBOW,
-  DBOW,
-  RHEEL,
-  LHEEL,
-  RTOE,
-  LTOE,
-  FLAGEOLET,
-  OPEN,
-  PRALLMORDENT,
-  PRALL,
-  PRALLPRALL,
-  SEGNO,
-  SFORZATO,
-  STOPPED,
-  THUMB,
-  TRILL_ELEMENT,
-  TRILLELEMENT,
-  UPPRALL,
-  D_ARPEGGIO
-};
- 
-
-
-typedef struct chord
-{
-  GList *tones;			/* Holds pointers to actual note structures */
-  /* test for new dynamic handling */
-  GList *dynamics;
-  gboolean has_dynamic;
-  gint highestpitch;
-  gint lowestpitch;
-  gint highesty;
-  gint lowesty;
-  gint baseduration;
-  gint numdots;
-  gint sum_mid_c_offset;
-  gint numtones;
-
-  gboolean is_tied;
-  gboolean is_stemup;
-  gboolean is_reversealigned;
-  gboolean slur_begin_p;
-  gboolean slur_end_p;
-  gboolean crescendo_begin_p;
-  gboolean crescendo_end_p;
-  gboolean diminuendo_begin_p;
-  gboolean diminuendo_end_p;
-  gboolean hasanacc;
-  /*Flag to show whether note is a grace note*/
-  gboolean is_grace;
-  gboolean struck_through; /*Flag for a struck through stem*/
-  gint stemy;		/* Stores the y position of the end of the stem */
-  GList *ornamentlist;
-  /* Awaiting deletion as been replaced by ornamentlist
-  gboolean has_stacatto_p; 
-  gboolean is_accented_p; 
-  gboolean has_fermata_p; 
-  gboolean has_tenuto_p;
-  gboolean has_trill_p;
-  gboolean has_turn_p;
-  gboolean has_mordent_p;
-  gboolean has_staccatissimo_p;
-  gboolean has_marcato_p;
-  gboolean has_ubow_p;
-  gboolean has_dbow_p;
-  gboolean has_rheel_p;
-  gboolean has_lheel_p;
-  gboolean has_rtoe_p;
-  gboolean has_ltoe_p; 
-  */
-
-  /* Note highlighting flag if
-   * true change notes colour
-   */
-  gboolean is_highlighted; 
-
-  GString *lyric;
-  gboolean is_syllable;
-  gboolean center_lyric;
-  gboolean is_figure; /* the reason for using this boolean is to exploit 
-			 the fact that all the spacing and printing of 
-			 figures can use the code for the CHORD type */
-  gpointer figure; /* when this chord is a bass note 
-		      (figure !=NULL && is_figure==FALSE) this
-		      pointer points to an objnode in a FiguredBassStaff.
-		      That objnode's data is a mudelaobject of type CHORD.
-		      It is linked into the corresponding FiguredBassStaff if
-		      one exists.
-		      When this chord is_figure then figure is a 
-		      GString* containing the
-		      figures in lilypond format. */
-}
-chord;
-
-/* Indicator that a tuplet is starting */
-
-typedef struct tupopen
-{
-  gint numerator;
-  gint denominator;
-}
-tupopen;
-
-enum clefs
-{
-  DENEMO_TREBLE_CLEF,
-  DENEMO_BASS_CLEF,
-  DENEMO_ALTO_CLEF,
-  DENEMO_G_8_CLEF,
-  DENEMO_TENOR_CLEF,
-  DENEMO_SOPRANO_CLEF
-};
-
-/* Indicator for a clef change */
-
-typedef struct clef
-{
-  enum clefs type;
-}
-clef;
-
-/* Indicator for a time-signature change. Only appears at the
- * beginning of a measure */
-
-typedef struct timesig
-{
-  gint time1;
-  gint time2;
-}
-timesig;
-
-/* Indicator for a key-signature change. */
-
-typedef struct keysig
-{
-  gint number;
-  gboolean isminor;
-  gint accs[7];
-}
-keysig;
-
-/* Dynamic */
-
-typedef struct dynamic 
-{
-  GString *type;
-}
-dynamic;
-
-enum barline_type {
-  ORDINARY_BARLINE,
-  DOUBLE_BARLINE,
-  END_BARLINE,
-  OPENREPEAT_BARLINE,
-  CLOSE_REPEAT,
-  OPEN_CLOSE_REPEAT
-};
-
-typedef struct barline
-{
-  gint type;
-}
-barline;
-
-/* Data structure for an arbitrary directive to be passed to
- * Lilypond that Denemo doesn't understand. This type is useful
- * in that the user can insert such directives into a mudela file
- * by hand and have Denemo respect them when it loads a file and
- * write them back when it saves it */
-
-
-/* Lyric datastructure */
-typedef struct lyric
-{
-  GString *lyrics;
-  gint position;
-  gboolean is_syllable;
-  gboolean center_lyric;
-}lyric;
-
-
-typedef struct lilydirective
-{
-  GString *directive;
-}
-lilydirective;
-
-enum stemdirections
-{
-  DENEMO_STEMDOWN=1,
-  DENEMO_STEMBOTH,
-  DENEMO_STEMUP
-};
-
-/* Indicator that the following music should be all stemup, all
- * stemdown, or stemmed normally */
-
-typedef struct stemdirective
-{
-  enum stemdirections type;
-}
-stemdirective;
-
-/* A comment in the mudela file; treated similarly to a lilydirective.  */
-
-typedef struct mudelacomment
-{
-  GString *text;
-}
-mudelacomment;
-
-/* obsolete union as been replaced by void pointer instead
- typedef union mudelaobjunion
-{
-  chord chordval;
-  tupopen tupval;
-  clef clefval;
-  timesig timeval;
-  keysig keyval;
-  dynamic dynval;
-  barline blval;
-  lilydirective lilyval;
-  mudelacomment commentval;
-  stemdirective stemval;
-  grace graceval;
-}
-mudelaobjunion;
+/**
+ * Contains all the top-level information of an musical object
+ * the object pointer contains the actual object
  */
-
 typedef struct mudelaobject
 {
   enum objtype type;
@@ -415,7 +148,13 @@ typedef struct mudelaobject
 }
 mudelaobject;
 
-
+typedef enum denemocontext 
+{
+  DENEMO_NONE=1,
+  DENEMO_PIANO,
+  DENEMO_GROUP,
+  DENEMO_CHOIR
+}denemocontext;
 /* The ->data part of each measurenode points to an objlist, which is
    a list of the musical objects in that measure. */
 
@@ -426,7 +165,7 @@ typedef struct staff
   measurenode *measures;
   gint sclef;
   gint skey;
-  gint skey_isminor;
+  gint skey_isminor;  //25112005 Changed use to incorporate modes values 0 - major, 1 - minor, 2 - mode
   gint skeyaccs[7];
   gint stime1;
   gint stime2;
@@ -437,7 +176,8 @@ typedef struct staff
   gint leftmost_time2context;
   gint leftmost_keyaccs[7];
   gint leftmost_stem_directive;
-
+  /*New variable to define the context in which this staff appears*/
+  denemocontext context; 
   /*
    * Staff Parameters
    * Added Adam Tee 27/1/2000, 2001 
@@ -489,29 +229,30 @@ staff_info;
 union func_union
 {
   GtkFunction nocallback;
-  //GtkItemFactoryCallback1 callback;
-  //GCallback callback;
   GActionCallback callback;
 };
 
-struct keybinding_info
+typedef struct keybinding_info
 {
   gint keyval;
   gint state;
   gint command_number;
   gint callback_action;
   union func_union func;
-};
+}keybinding_info;
 
-struct keymap
+typedef struct keymap
 {
   GList **commands;
   GHashTable *quick_lookup_hashes;
-};
+}keymap;
 
-/* prefinfo holds information on user preferences. */
 
-struct prefinfo
+#define MAX_HISTORY 10
+/**
+ * prefinfo holds information on user preferences. 
+ */
+typedef struct prefinfo
 {
   GString *lilypath;
   GString *midiplayer;
@@ -520,14 +261,26 @@ struct prefinfo
   gboolean immediateplayback;
   gboolean lilyentrystyle;
   gboolean createclones;
+  gboolean articulation_palette;
+  gboolean notation_palette;
   /*Auto save data*/
   gboolean autosave;
   gint autosave_timeout;
   GString *browser;
-  struct keymap *the_keymap;
-};
+  GString *csoundcommand;
+  GString *csoundorcfile;
+  gboolean rtcs;
+  GString *pdfviewer;
+  GString *texteditor;
+  GQueue *history; //Queue to contain recently opened files
+  keymap *the_keymap;
+}prefinfo;
 
-struct mudelaheaderinfo {
+/**
+ * Contains all the lilypond header information
+ *
+ */
+typedef struct mudelaheaderinfo {
 /* Mudela file header information */
   GString *title;
   GString *subtitle;
@@ -545,13 +298,49 @@ struct mudelaheaderinfo {
   GString *tagline;
 /*  GString *; */
 
-};
+}mudelaheaderinfo;
 
-/*
- * Undo data. holds data for undo 
+typedef enum InstrumentType
+{
+  WOODWIND,
+  BRASS,
+  STRINGS,
+  VOCALS,
+  PITCHEDPERCUSSION,
+  PLUCKEDSTRINGS,
+  KEYBOARDS,
+  NONE
+}InstrumentType;
+
+/**
+ * Structure to contain the list of Instruments for the score
+ * configuration wizard
+ *
+ */
+typedef struct InstrumentConfig
+{
+	GString *name;
+	GString *midiinstrument;
+	gint sclef;
+	gint transposition;
+	gint numstaffs;
+
+}InstrumentConfig;
+
+/**
+ * Stores global instrument type and a list of InstrumentConfig structures
+ */
+typedef struct InstrumentList
+{
+	InstrumentType type;
+	GList *instruments;  // List to contain a list of Instruments of given type
+}InstrumentList;
+
+/**
+ * Contains data required for undo operation 
  * Borrowed idea from GScore
  */
-struct undo_data
+typedef struct undo_data
 {
   gpointer object;    /* pointer to object deleted */
   gint staffnum;      /* staff number */     
@@ -559,24 +348,50 @@ struct undo_data
   gint position;      /* position in bar */
   enum action_type action; /*action type */
 
-};
+}undo_data;
  
-/* Redo data 
+/**
  * Contains data required for redo operation 
  * contents as per undo_data
  */
-struct redo_data
+typedef struct redo_data
 {
   gpointer object;
   gint staffnum;
   gint measurenum;
-  gint measure;
   gint position;
   enum action_type action;
-};
+}redo_data;
 
 
-/* struct scoreinfo is actually a somewhat misleading name.  It contains
+/**
+ * Structure to hold bookmark information
+ * Id - gint
+ * Bar - gint
+ * Staff - gint
+ */
+typedef struct bookmark
+{
+  gint id;
+  gint bar;
+  gint staff;
+}bookmark;
+
+/** 
+ * Contains paper score configuration
+ *
+ */
+typedef struct scoreconfig 
+{
+	GString *papersize;
+	gint fontsize;
+	GString	*lilyversion;
+	gboolean orientation;
+	
+}scoreconfig;
+
+/**
+ * struct scoreinfo is actually a somewhat misleading name.  It contains
  * within it a struct prefinfo *, and when Denemo supports editing
  * multiple scores simultaneously, each score's scoreinfo structure will
  * contain a pointer to the same single prefinfo structure.
@@ -588,9 +403,10 @@ struct redo_data
  * structure, and a handful need access to the prefinfo structure as
  * well. Only the preferences dialog needs access to _just_ the
  * prefinfo structure.  So, why not keep things simple and always pass
- * around scoreinfos? */
+ * around scoreinfos?
+  */
 
-struct scoreinfo
+typedef struct scoreinfo
 {
 	/*Indicator for open file readonly*/
   gint readonly;
@@ -616,7 +432,7 @@ struct scoreinfo
   GList *curlilynode; /* the node of the lily parse tree on display 
 			 in textwindow */
   GList *lily_file; /* root of lily file parse, see lilyparser.y etc  */
-  
+	scoreconfig *config; //Contains the paper configuration of the score
   gint status_context_id;
   gint leftmeasurenum; /* start at 1 */
   gint rightmeasurenum;/* start at 1 */
@@ -707,32 +523,31 @@ struct scoreinfo
   GList *scoreblocks;
 
   /*list of undo data */
-  GList *undodata;
+  GQueue *undodata;
   gint undo_level; /*denotes undo level */
-  GList *redodata;
+  GQueue *redodata;
   gint redo_level;
   gint undo_redo_mode;
 
   /* UI manager */
   GtkUIManager *ui_manager;
-
+  scoreconfig *sconfig;
   /* Articulation palette window */
   GtkWidget* articulation_palette;
-};
 
+  GtkWidget *progressbar;
+  GList *bookmarks;
+  
+  GList *Instruments;
+  
+}scoreinfo;
 
 
-typedef struct denemo_plugin
-{
-  void (* plugin_init) (struct scoreinfo *si); /*Initialisation Function*/
-  void (* plugin_cleanup) (struct scoreinfo *si); /*Cleanup Function */
-  GString *title; /*Name of plugin */
-}denemo_plugin;
-
 
 /*Forward Declaration*/
 typedef struct _PluginData PluginData;
-/* Structure borrowed from Gnumeric which 
+/**
+ * Structure borrowed from Gnumeric which 
  * allows us to unload a plugin.
  * This should render the denemo_plugin struct redundant.
  */
@@ -746,4 +561,8 @@ struct _PluginData {
 
 #define g_malloc(a) g_malloc0(a) /* for extensible debuggable code */
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif  /* #ifndef DENEMO_DATASTRUCTURES  */
