@@ -3,7 +3,7 @@
  *  articulation callback prototypes 
  * 
  *  for Denemo, a gtk+frontend to GNU Lilypond	
- *  (c) 2001 Adam
+ *  (c) 2001-2005 Adam
  */
 
 #ifndef ARTICULATIONS_H
@@ -12,13 +12,12 @@
 enum articulationcallbackaction
 { GENERAL, STRING, ORGAN };
 
-//static void
-//insert_artic (GtkWidget *widget, gpointer data);
-
-void insert_articulation (gpointer callback_data, guint callback_action,
-			  GtkWidget *widget);
 
 int set_articulation(gchar *string, mudelaobject *obj);
 
 
+void toggle_articulation_palette (GtkAction *action, struct scoreinfo *si);
+void popup_articulation_palette (GtkAction *action, struct scoreinfo *si);
+void articulation_dialog (GtkAction *action, struct scoreinfo *si);
+GList* insert_ornament_list(enum ornament orn, GList *list);
 #endif
