@@ -14,7 +14,7 @@ void newclefify (mudelaobject * thechord, gint dclef);
 
 void findreversealigns (mudelaobject * thechord);
 
-mudelaobject *newchord (gint baseduration, gint numdots);
+mudelaobject *newchord (gint baseduration, gint numdots, int tied);
 
 void addtone (mudelaobject * mudelaobj, gint mid_c_offset, gint enshift,
 	      gint dclef);
