@@ -10,6 +10,6 @@
 #include <denemo/denemo.h>
 
 void find_leftmost_staffcontext (staff * curstaffstruct,
-				 struct scoreinfo *si);
+				 scoreinfo *si);
 
-void find_leftmost_allcontexts (struct scoreinfo *si);
+void find_leftmost_allcontexts (scoreinfo *si);
