@@ -9,8 +9,8 @@
 
 #include <denemo/denemo.h>
 
-void insertlyric(GtkWidget *widget, gpointer data);
-void lyric_insert(GtkAction *action, gpointer callback_data);
+void insertlyric(gpointer data);
+void lyric_insert(GtkAction *action, scoreinfo *si);
 mudelaobject *
 newlyric (gint baseduration, gint numdots, gchar *lys);
 
