@@ -16,7 +16,7 @@ struct fourints
 };
 
 measurenode *
-addmeasures (struct scoreinfo *si, gint pos, guint nummeasures);
+addmeasures (struct scoreinfo *si, gint pos, guint nummeasures, gint all);
 
 void
 freeobjlist (gpointer data, gpointer user_data);
