@@ -5,6 +5,8 @@
    for Denemo, a gtk+ frontend to GNU Lilypond
    (c) 2000-2005 Matthew Hiller
 */
+#ifndef MOVEVIEWPORT_H
+#define MOVEVIEWPORT_H
 
 #include <denemo/denemo.h>
 
@@ -40,3 +42,7 @@ vertical_scroll (GtkAdjustment *adjust, struct scoreinfo *si);
 
 void
 horizontal_scroll (GtkAdjustment *adjust, struct scoreinfo *si);
+
+void set_currentstaffnum(struct scoreinfo *si, gint dest);
+
+#endif
