@@ -4,6 +4,8 @@
  * for Denemo, a gtk+ frontend to GNU Lilypond
  * (c) 1999-2005 Matthew Hiller
  */
+#ifndef OBJOPS_H
+#define OBJOPS_H 
 
 #include <denemo/denemo.h>
 
@@ -20,7 +22,7 @@ void
 initkeyaccs (gint *accs, gint number);
 
 mudelaobject *
-newkeyobj (gint number, gboolean isminor);
+newkeyobj (gint number, gint isminor, gint mode); /* default mode: 0 */
 
 mudelaobject *
 newmeasurebreakobject ();
@@ -44,3 +46,7 @@ lyric_new(gchar *type, gint position, gboolean syllable);
 *  no object is associated. */
 mudelaobject *
 newobj(enum objtype type);
+
+
+void setinitialkeysig(staff *curstaff, gint tokey, gint type);
+#endif
