@@ -7,6 +7,6 @@ void
 playback_local (gpointer callback_data, guint callback_action,
 		GtkWidget * widget);
 void
-playback (gpointer callback_data, guint callback_action, GtkWidget * widget);
+playback (GtkAction *action, scoreinfo *si);
 
 #endif //PLAYBACKH
