@@ -17,6 +17,7 @@ load_plugin(GtkAction *action, gpointer callback_data);
 void list_loaded_plugins(GtkAction *action, gpointer callback_data);
 void list_available_plugins(GtkAction *action, gpointer callback_data);
 void unloadplugins(GtkAction *action, gpointer callback_data);
-
+void denemo_plugin_init (const gchar * name, struct scoreinfo *si);
+gint denemo_plugin_cleanup(const gchar *name, struct scoreinfo *si);
 char *stripname (char *d_name);
 #endif /* _PLUGIN_H */
