@@ -4,7 +4,7 @@
 #include <denemo/denemo.h> 
 
 void
-print(gpointer callback_data, guint callback_action, GtkWidget *widget);
+print(GtkAction *action, gpointer callback_data);
 
 
 #endif /*PRINT_H*/	
