@@ -3,6 +3,8 @@
 
  * for Denemo, a gtk+ frontend to GNU Lilypond
  * (c) 2000-2005 Matthew Hiller */
+#ifndef SCOREOPS_H
+#define SCOREOPS_H
 
 #include <denemo/denemo.h>
 
@@ -13,3 +15,6 @@ void free_score (struct scoreinfo *si);
 /* get rid of the lily parse tree of a score and its window; hide its status bar */
 void abandon_lily_tree(scoreinfo *si);
 struct mudelaheaderinfo *new_mudela_header();
+scoreconfig * new_score_config();
+
+#endif
