@@ -55,8 +55,8 @@ void
 saveselwrapper(GtkAction *action, gpointer data);
 void undowrapper(GtkAction *action, gpointer data);
 void redowrapper(GtkAction *action, gpointer data);
-void undo(struct scoreinfo *si);
-void redo(struct scoreinfo *si);
-void update_undo_info(struct scoreinfo *si, struct undo_data *undo);
-void update_redo_info(struct scoreinfo *si, struct redo_data *redo);
+void undo(scoreinfo *si);
+void redo(scoreinfo *si);
+void update_undo_info(scoreinfo *si, undo_data *undo);
+void update_redo_info(scoreinfo *si, redo_data *redo);
 #endif
