@@ -30,7 +30,6 @@
 #include "selectops.h"
 #include "staffops.h"
 #include "utils.h"
-#include "lilydirectives.h"
 #include "dynamic.h"
 #include "lyric.h"
 #include "figure.h"
@@ -42,6 +41,8 @@
 #include "plugin.h"
 #include "runsilent.h"
 
+
+
 void newview(void);
 void createview(GtkAction *action,gpointer data);
 void closeit (GtkWidget * widget, gpointer data);
@@ -50,4 +51,13 @@ void closewrapper (GtkAction *action,gpointer data);
 void openinnew(GtkAction *action,gpointer data);
 void close_view( GtkWidget *widget, gpointer data);
 void closeview(GtkAction *action,gpointer data);
+void addhistorymenuitem(gpointer data, gpointer user_data);
+
+//TODO Fix for automatic updating during operation
+//
+struct cbd
+{
+	scoreinfo *si;
+	GtkWidget *menu;
+};
 #endif
